Errores
====================



Al tratar de convertir una letra de *Marke37* a HTML pueden surgir varios errores. He aquí el compendio de las cosas que pueden ir mal y cómo solucionarlas.



Error 01 - No se encontró un título en el documento
---------------------------------------------------